==> aliyun-python-sdk-ess-2.2.1.tar.gz: aliyun-python-sdk-ess-2.2.1/aliyunsdkess/request/v20140828/RecordLifecycleActionHeartbeatRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class RecordLifecycleActionHeartbeatRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'RecordLifecycleActionHeartbeat','ESS')

	def get_lifecycleActionToken(self):
		return self.get_query_params().get('lifecycleActionToken')

	def set_lifecycleActionToken(self,lifecycleActionToken):
		self.add_query_param('lifecycleActionToken',lifecycleActionToken)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_heartbeatTimeout(self):
		return self.get_query_params().get('heartbeatTimeout')

	def set_heartbeatTimeout(self,heartbeatTimeout):
		self.add_query_param('heartbeatTimeout',heartbeatTimeout)

	def get_lifecycleHookId(self):
		return self.get_query_params().get('lifecycleHookId')

	def set_lifecycleHookId(self,lifecycleHookId):
		self.add_query_param('lifecycleHookId',lifecycleHookId)

	def get_OwnerAccount(self):
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self,OwnerAccount):
		self.add_query_param('OwnerAccount',OwnerAccount)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)

==> aliyun-python-sdk-ess-2.2.7.tar.gz: aliyun-python-sdk-ess-2.2.7/aliyunsdkess/request/v20140828/RecordLifecycleActionHeartbeatRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
class RecordLifecycleActionHeartbeatRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Ess', '2014-08-28', 'RecordLifecycleActionHeartbeat')

	def get_lifecycleActionToken(self):
		return self.get_query_params().get('lifecycleActionToken')

	def set_lifecycleActionToken(self,lifecycleActionToken):
		self.add_query_param('lifecycleActionToken',lifecycleActionToken)

	def get_ResourceOwnerAccount(self):
		return self.get_query_params().get('ResourceOwnerAccount')

	def set_ResourceOwnerAccount(self,ResourceOwnerAccount):
		self.add_query_param('ResourceOwnerAccount',ResourceOwnerAccount)

	def get_heartbeatTimeout(self):
		return self.get_query_params().get('heartbeatTimeout')

	def set_heartbeatTimeout(self,heartbeatTimeout):
		self.add_query_param('heartbeatTimeout',heartbeatTimeout)

	def get_lifecycleHookId(self):
		return self.get_query_params().get('lifecycleHookId')

	def set_lifecycleHookId(self,lifecycleHookId):
		self.add_query_param('lifecycleHookId',lifecycleHookId)

	def get_OwnerAccount(self):
		return self.get_query_params().get('OwnerAccount')

	def set_OwnerAccount(self,OwnerAccount):
		self.add_query_param('OwnerAccount',OwnerAccount)

	def get_OwnerId(self):
		return self.get_query_params().get('OwnerId')

	def set_OwnerId(self,OwnerId):
		self.add_query_param('OwnerId',OwnerId)
